@@ -11,7 +11,7 @@ use POSIX qw( strftime );
 use Moo;
 with "Archive::BagIt::Role::Portability";
 
-our $VERSION = '0.088'; # VERSION
+our $VERSION = '0.089'; # VERSION
 
 # ABSTRACT: The main module to handle bags.
 
@@ -60,7 +60,7 @@ has 'use_async' => (
 has 'force_utf8' => (
     is        => 'rw',
     lazy      => 1,
-    predicate => 1,
+    predicate => 'has_force_utf8',
 );
 
 ###############################################
@@ -72,8 +72,8 @@ has 'bag_path' => (
 
 # if the user wants specific plugins!
 has 'use_plugins' => (
-    is   => 'rw',
-    lazy => 1,
+    is       => 'rw',
+    lazy     => 1,
 );
 
 ###############################################
@@ -179,7 +179,7 @@ has 'bag_info' => (
     is        => 'rw',
     lazy      => 1,
     builder   => '_build_bag_info',
-    predicate => 1
+    predicate => 'has_bag_info'
 );
 
 ###############################################
@@ -417,11 +417,16 @@ sub add_or_replace_baginfo_by_key {
 
 
 has 'forced_fixity_algorithm' => (
-    is   => 'ro',
-    lazy => 1,
-    builder  => '_build_forced_fixity_algorithm',
+    is        => 'ro',
+    lazy      => 1,
+    builder   => '_build_forced_fixity_algorithm',
 );
 
+sub has_forced_fixity_algorithm {
+    my $self = shift;
+    return (defined $self->forced_fixity_algorithm() );
+} # false if use_plugins used
+
 ###############################################
 
 
@@ -754,11 +759,15 @@ sub _build_non_payload_files {
 
 sub _build_forced_fixity_algorithm {
     my ($self) = @_;
-    if ($self->bag_version() >= 1.0) {
-        return Archive::BagIt::Plugin::Algorithm::SHA512->new(bagit => $self);
-    }
-    else {
-        return Archive::BagIt::Plugin::Algorithm::MD5->new(bagit => $self);
+    if ($self->use_plugins()) {
+        return;
+    } else {
+        if ($self->bag_version() >= 1.0) {
+            return Archive::BagIt::Plugin::Algorithm::SHA512->new(bagit => $self);
+        }
+        else {
+            return Archive::BagIt::Plugin::Algorithm::MD5->new(bagit => $self);
+        }
     }
 }
 
@@ -809,23 +818,26 @@ sub verify_bag {
     my $version = $self->bag_version(); # to call trigger
     my $encoding = $self->bag_encoding(); # to call trigger
     my $baginfo = $self->verify_baginfo(); #to call trigger
-    my $forced_fixity_alg = $self->forced_fixity_algorithm()->name();
+
     my $fetch_file = File::Spec->catfile($self->metadata_path, "fetch.txt");
-    my $manifest_file = File::Spec->catfile($self->metadata_path, "manifest-$forced_fixity_alg.txt");
     my $payload_dir   = $self->payload_path;
     my $return_all_errors = $opts->{return_all_errors};
 
     if (-f $fetch_file) {
         croak("Fetching via file '$fetch_file' is not supported by current Archive::BagIt implementation")
     }
-    croak("Manifest '$manifest_file' is not a regular file or does not exist for given bagit version '$version'") unless -f ($manifest_file);
+    # check forced fixity
+    if ($self->has_forced_fixity_algorithm()) {
+        my $forced_fixity_alg = $self->forced_fixity_algorithm()->name();
+        my $manifest_file = File::Spec->catfile($self->metadata_path, "manifest-$forced_fixity_alg.txt");
+        croak("Manifest '$manifest_file' is not a regular file or does not exist for given bagit version '$version'") unless -f ($manifest_file);
+    }
     croak("Payload-directory '$payload_dir' is not a directory or does not exist") unless -d ($payload_dir);
 
     unless ($version > .95) {
         croak ("Bag Version $version is unsupported");
     }
 
-    # check forced fixity
 
     my @errors;
 
@@ -980,7 +992,7 @@ Archive::BagIt - The main module to handle bags.
 
 =head1 VERSION
 
-version 0.088
+version 0.089
 
 =head1 NAME
 
@@ -1198,7 +1210,9 @@ The arguments are:
 =item C<use_parallel> - if set it uses Parallel::parallel_map to calculate digests of payload files in parallel,
       only useful if underlying filesystem supports parallel read and if multiple CPU cores available.
 
-=item C<use_plugins> - expected manifest plugin strings, if set it uses the requested plugins, example C<Archive::BagIt::Plugin::Manifest::SHA256>
+=item C<use_plugins> - expected manifest plugin strings, if set it uses the requested plugins,
+      example C<Archive::BagIt::Plugin::Manifest::SHA256>.
+      HINT: this option *disables* the forced fixity check in C<verify_bag()>!
 
 =back
 
@@ -1385,13 +1399,13 @@ existing values in internal bag-info representation will be overwritten!
 
 store a bagit-obj if bagit directory-structure was already constructed.
 
-=head2 init_metadata()
+=head2 init_metadata( $bag_path, $options)
 
 A constructor that will just create the metadata directory
 
 This won't make a bag, but it will create the conditions to do that eventually
 
-=head2 make_bag( $bag_path )
+=head2 make_bag( $bag_path, $options )
 
 A constructor that will make and return a bag from a directory,
 
